@@ -1089,7 +1089,7 @@ glamor_egl_init(ScrnInfoPtr scrn, int fd)
     Bool force_es = FALSE;
     const char *glvnd_vendor = NULL;
 
-    glamor_egl = calloc(sizeof(*glamor_egl), 1);
+    glamor_egl = calloc(1, sizeof(*glamor_egl));
     if (glamor_egl == NULL)
         return FALSE;
     if (xf86GlamorEGLPrivateIndex == -1)
